'use strict';

var config = require('../config/Default.js');

var store = {};

store.sendResponse = function (module_name,code,message,data,error, callback) {
  var response = {};  

  if (code === config.sequelize_code) {
    if (error.name == 'SequelizeDatabaseError') {
      response.code = 501;
    }
    else if (error.name == 'SequelizeValidationError') {
      response.code = 422;
    }
    else {
      response.code = 501;
    }
  }
  else if (code === config.cassandra_code) {
    if (error.name == 'apollo.model.validator.invalidvalue') {
      response.code = 422;
    }
    else {
      response.code = 501;
    }
  }
  else {
    response.code = code;
  }
  response = store.getResponse(response.code);  
  response.code = module_name + '-' + response.code;


  if (data != null) {
    if (!data.hasOwnProperty('rows')) {
      response.data = data;
    }
    else {
      response.count = data.count;
      response.data = data.rows;
    }
  }
  if (error != null) response.error = error;
  if (message != null) response.message = message;
  callback(response);
}

store.getResponse = function (status) {
  var statusObj = {
    200: {
      "code": 200,
      "status": "success",
      "count": 0,
      "data": {
        // Application-specific data would go here. 
      },
      "message": null // Or optional success message 
    },
    201: {
      "code": 201,
      "status": "created",
      "data": {
        // Application-specific data would go here. /
      },
      "message": null // Or optional success message /
    },
    500: {
      "code": 500,
      "status": "Error",
      "message": "Server Error!",
      "error": {}
    },
    501: {
      "code": 501,
      "status": "DB Error",
      "message": "Query is wrong.",
      "error": {}
    },
    550: {
      "code": 550,
      "status": "Send email",
      "message": "Requested action not taken: mailbox unavailable",
      "error": {}
    },
    400: {
      "code": 400,
      "status": "Bad Request",
      "message": "Validation failed.",
      "error": {}
    },
    422: {
      "code": 422,
      "status": "Unprocesseable Entity",
      "message": "Validation failed.",
      "error": {}
    },
    409: {
      "code": 409,
      "status": "Conflict",
      "message": "Data duplication error.",
      "error": {}
    },
    405: {
      "code": 405,
      "status": "Method not allowed.",
      "message": "Incorrect method. Try with ",
      "error": {}
    },
    406: {
      "code": 406,
      "status": "Not acceptable.",
      "message": "Incorrect Content-Type. Try with application/json.",
      "error": {}
    },
    413: {
      "code": 413,
      "status": "Request Entity Too Large.",
      "message": "File is too large.",
      "error": {}
    },
    415: {
      "code": 415,
      "status": "Unsupported Media Type.",
      "message": "File format is not supported.",
      "error": {}
    },
    507: {
      "code": 507,
      "status": "Insufficient Storage",
      "message": "File limit exceeded.",
      "error": {}
    }
  };
  return statusObj[status];
};

module.exports = store;